BMFMassTransitIntercityPolicy enum
公共交通:跨城公交换乘策略
- Inheritance
-
- Object
- Enum
- BMFMassTransitIntercityPolicy
Values
- TIME_FIRST → const BMFMassTransitIntercityPolicy
-
较快捷
- START_EARLY → const BMFMassTransitIntercityPolicy
-
出发早
- PRICE_FIRST → const BMFMassTransitIntercityPolicy
-
价格低
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BMFMassTransitIntercityPolicy> - A constant List of the values in this enum, in order of their declaration.