BMFReverseGeoShareURLOption class

反geo短串分享检索信息类

Inheritance
  • Object
  • BMFSearch
  • BMFReverseGeoShareURLOption

Constructors

BMFReverseGeoShareURLOption({required BMFCoordinate? location, String? name, String? snippet})
构造方法
BMFReverseGeoShareURLOption.fromMap(Map map)
map => BMFReverseGeoShareURLOption

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
getter方法 用于区分不同搜索结果
no setterinherited
location ↔ BMFCoordinate?
经纬度
getter/setter pair
name ↔ String?
名称
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ String?
通过短URL调起客户端时作为附加信息显示在名称下面
getter/setter pair

Methods

fromMap(Map map) → dynamic
map -> dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
model -> map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited