BMFTrainVehicleInfo class

公共交通方案里的交通工具信息类 - 火车

Inheritance

Constructors

BMFTrainVehicleInfo({String? name, String? departureStation, String? arriveStation, String? departureTime, String? arriveTime, double? price, String? booking})
有参构造
BMFTrainVehicleInfo.fromMap(Map map)
map => BMFTrainVehicleInfo

Properties

arriveStation ↔ String?
到达站
getter/setter pairinherited
arriveTime ↔ String?
到达时间(BMFBusVehicleInfo时arriveTime为空)
getter/setter pairinherited
booking ↔ String?
订票电话
getter/setter pair
departureStation ↔ String?
出发站
getter/setter pairinherited
departureTime ↔ String?
出发时间(BMFBusVehicleInfo时departureTime为空)
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
该交通路线的名称
getter/setter pairinherited
price ↔ double?
价格(单位:元)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromMap(Map map) → dynamic
map -> dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
model -> map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited