BMFWalkingRoutePlanOption class

步行查询基础信息类

Inheritance

Constructors

BMFWalkingRoutePlanOption({required BMFPlanNode from, required BMFPlanNode to})
有参构造
BMFWalkingRoutePlanOption.fromMap(Map map)
map => BMFWalkingRoutePlanOption

Properties

from BMFPlanNode?
路线规划的起点
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
getter方法 用于区分不同搜索结果
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to BMFPlanNode?
路线规划的终点
getter/setter pairinherited

Methods

fromMap(Map map) → dynamic
map -> dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
model -> map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited